# -*- coding: UTF-8 -*-
# =================================
#  ルートフォルダパス
# =================================
LOG_PATH = "log/"
